@@ -8,7 +8,7 @@
 #' @param mapping The aesthetic mapping, usually constructed with
 #'   \code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_}}. Only needs
 #'   to be set at the layer level if you are overriding the plot defaults.
-#' @param data A layer specific dataset - only needed if you want to override
+#' @param data A layer specific data set - only needed if you want to override
 #'   the plot defaults.
 #' @param geom The geometric object to use display the data
 #' @param position The position adjustment to use for overlapping points on this
@@ -511,8 +511,8 @@ StatFitAugment <-
                    ggplot2::Stat,
                    compute_group = fit_augment_compute_group_fun,
                    default_aes =
-                     ggplot2::aes(ymax = ..y.. + ...se.fit.. * ..t.value..,
-                                  ymin = ..y.. - ...se.fit.. * ..t.value..),
+                     ggplot2::aes(ymax = stat(y + .se.fit * t.value),
+                                  ymin = stat(y - .se.fit * t.value)),
                    required_aes = c("x", "y")
 )
 
